import { __decorate, __metadata } from 'tslib';
import { LoadingBarService, LoadingBarModule } from '@ngx-loading-bar/core';
import { Injectable, NgModule } from '@angular/core';
import { HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http';
import { finalize } from 'rxjs/operators';

let LoadingBarInterceptor = class LoadingBarInterceptor {
    constructor(loader) {
        this.loader = loader;
        this.state = this.loader.useRef('http');
    }
    intercept(req, next) {
        // https://github.com/angular/angular/issues/18155
        if (req.headers.has('ignoreLoadingBar')) {
            return next.handle(req.clone({ headers: req.headers.delete('ignoreLoadingBar') }));
        }
        const r = next.handle(req);
        let started = false;
        const responseSubscribe = r.subscribe.bind(r);
        r.subscribe = (...args) => {
            this.state.start();
            started = true;
            return responseSubscribe(...args);
        };
        return r.pipe(finalize(() => started && this.state.complete()));
    }
};
LoadingBarInterceptor.ctorParameters = () => [
    { type: LoadingBarService }
];
LoadingBarInterceptor = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [LoadingBarService])
], LoadingBarInterceptor);

let LoadingBarHttpClientModule = class LoadingBarHttpClientModule {
};
LoadingBarHttpClientModule = __decorate([
    NgModule({
        imports: [
            HttpClientModule,
            LoadingBarModule,
        ],
        exports: [
            HttpClientModule,
            LoadingBarModule,
        ],
        providers: [
            { provide: HTTP_INTERCEPTORS, useClass: LoadingBarInterceptor, multi: true },
        ],
    })
], LoadingBarHttpClientModule);

/**
 * Generated bundle index. Do not edit.
 */

export { LoadingBarHttpClientModule, LoadingBarInterceptor as ɵa };
//# sourceMappingURL=ngx-loading-bar-http-client.js.map
